@@ -200,16 +200,16 @@ make_path(LV2_State_Make_Path_Handle handle, const char* path)
 
 static char*
 abstract_path(LV2_State_Map_Path_Handle handle,
-              const char*               absolute_path)
+              const char*               abs_path)
 {
 	LilvState*    state     = (LilvState*)handle;
 	char*         path      = NULL;
-	char*         real_path = lilv_realpath(absolute_path);
+	char*         real_path = lilv_realpath(abs_path);
 	const PathMap key       = { (char*)real_path, NULL };
 	ZixTreeIter*  iter      = NULL;
 
-	if (absolute_path[0] == '\0') {
-		return lilv_strdup(absolute_path);
+	if (abs_path[0] == '\0') {
+		return lilv_strdup(abs_path);
 	} else if (!zix_tree_find(state->abs2rel, &key, &iter)) {
 		// Already mapped path in a previous call
 		PathMap* pm = (PathMap*)zix_tree_get(iter);
@@ -259,26 +259,26 @@ abstract_path(LV2_State_Map_Path_Handle handle,
 
 static char*
 absolute_path(LV2_State_Map_Path_Handle handle,
-              const char*               abstract_path)
+              const char*               state_path)
 {
 	LilvState* state = (LilvState*)handle;
 	char*      path  = NULL;
-	if (lilv_path_is_absolute(abstract_path)) {
+	if (lilv_path_is_absolute(state_path)) {
 		// Absolute path, return identical path
-		path = lilv_strdup(abstract_path);
+		path = lilv_strdup(state_path);
 	} else if (state->dir) {
 		// Relative path inside state directory
-		path = lilv_path_join(state->dir, abstract_path);
+		path = lilv_path_join(state->dir, state_path);
 	} else {
 		// State has not been saved, unmap
-		path = lilv_strdup(lilv_state_rel2abs(state, abstract_path));
+		path = lilv_strdup(lilv_state_rel2abs(state, state_path));
 	}
 
 	return path;
 }
 
 /** Return a new features array which is @c feature added to @c features. */
-const LV2_Feature**
+static const LV2_Feature**
 add_features(const LV2_Feature *const * features,
              const LV2_Feature* map, const LV2_Feature* make)
 {
@@ -306,6 +306,19 @@ absolute_dir(const char* path)
 	return base;
 }
 
+static const char*
+state_strerror(LV2_State_Status st)
+{
+	switch (st) {
+	case LV2_STATE_SUCCESS:         return "Completed successfully";
+	case LV2_STATE_ERR_BAD_TYPE:    return "Unsupported type";
+	case LV2_STATE_ERR_BAD_FLAGS:   return "Unsupported flags";
+	case LV2_STATE_ERR_NO_FEATURE:  return "Missing features";
+	case LV2_STATE_ERR_NO_PROPERTY: return "Missing property";
+	default:                        return "Unknown error";
+	}
+}
+
 LILV_API
 LilvState*
 lilv_state_new_from_instance(const LilvPlugin*          plugin,
@@ -365,11 +378,18 @@ lilv_state_new_from_instance(const LilvPlugin*          plugin,
 		: NULL;
 
 	if (iface) {
-		iface->save(instance->lv2_handle, store_callback,
-		            state, flags, features);
+		LV2_State_Status st = iface->save(
+			instance->lv2_handle, store_callback, state, flags, features);
+		if (st) {
+			LILV_ERRORF("Error saving plugin state: %s\n", state_strerror(st));
+			free(state->props);
+			state->props     = NULL;
+			state->num_props = 0;
+		} else {
+			qsort(state->props, state->num_props, sizeof(Property), property_cmp);
+		}
 	}
 
-	qsort(state->props, state->num_props, sizeof(Property), property_cmp);
 	qsort(state->values, state->num_values, sizeof(PortValue), value_cmp);
 
 	free(sfeatures);
@@ -557,7 +577,7 @@ lilv_state_new_from_world(LilvWorld*      world,
 	}
 
 	LilvState* state = new_state_from_model(
-		world, map, world->model, node->val.uri_val, NULL);
+		world, map, world->model, node->node, NULL);
 
 	return state;
 }
@@ -585,7 +605,7 @@ lilv_state_new_from_file(LilvWorld*      world,
 	serd_reader_read_file(reader, node.buf);
 
 	SordNode* subject_node = (subject)
-		? subject->val.uri_val
+		? subject->node
 		: sord_node_from_serd_node(world->world, env, &node, NULL, NULL);
 
 	char* dirname   = lilv_dirname(path);
@@ -760,7 +780,7 @@ lilv_state_write(LilvWorld*       world,
 		SERD_CURIE, USTR("lv2:appliesTo"));
 
 	const SerdNode* plugin_uri = sord_node_to_serd_node(
-		state->plugin_uri->val.uri_val);
+		state->plugin_uri->node);
 
 	SerdNode subject = serd_node_from_string(SERD_URI, USTR(uri ? uri : ""));
 
